@@ -125,6 +125,9 @@ getMultipleTicks <- function(security,
 
     if (returnAs == "xts") {
 
+        ## Make timestamps unique
+        res[,1] <- xts::make.index.unique(res[,1], eps=2e-6)
+
         ## Subset into blocks for each event type, creating xts
         rl <- lapply(eventType,
                  function(s) {
@@ -138,9 +141,9 @@ getMultipleTicks <- function(security,
         ## Use na.locf to carry bid, ask, .. forward, but do not use trade column
         ind <- !grepl("trade", colnames(x))
         x[,ind] <- zoo::na.locf(x[,ind])
-
+        
+        zoo::index(x) <- trunc(zoo::index(x)) # truncated time stamp down to seconds
         return(x)
-
     } 
         
     return(res)
